%global         pypi_name      cobaya

%define         debug_package  %{nil}

%ifnarch %arm32 %ix86
%bcond_without  mpi
%else
%bcond_with     mpi
%endif

Name:           python-cobaya
Version:        3.5.4
Release:        %mkrel 1
Summary:        A python sampler for Bayesian analysis
License:        LGPLv3
Group:          Development/Python
URL:            https://pypi.python.org/pypi/cobaya
Source0:        %{pypi_source}

#a dep (mpi4py) has arch-dependent existence
#BuildArch:      noarch


#use thefuzz instead of deprecated fuzzywuzzy package
Patch0:         cobaya-3.5-thefuzz.patch
#remove fallback to potentially inexistent initpowerlaw class
Patch1:         cobaya-3.3.1-cambinitpower.patch
#missing method in class
#Patch2:         cobaya-3.3.1-trieswarning.patch

%description
Cobaya (code for bayesian analysis, and Spanish for Guinea Pig) is a
framework for sampling and statistical modelling: it allows you to
explore an arbitrary prior or posterior using a range of Monte Carlo
samplers (including some advanced MCMC and nested samplers). The
results of the sampling can be analysed with GetDist. It supports MPI
parallelization.


%package -n python3-cobaya
Summary:        A python sampler for Bayesian analysis
Group:          Development/Python
%{?python_provide:%python_provide python3-cobaya}
BuildRequires:  python3
BuildRequires:  python3dist(setuptools)
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(scipy)
BuildRequires:  python3dist(pandas)
BuildRequires:  python3dist(pyyaml)
BuildRequires:  python3dist(requests)
BuildRequires:  python3dist(py-bobyqa)
BuildRequires:  python3dist(getdist)
BuildRequires:  python3dist(thefuzz)
BuildRequires:  python3dist(tqdm)
BuildRequires:  python3dist(portalocker)
BuildRequires:  python3dist(dill)
Requires:       python3dist(packaging)
Requires:       python3dist(pytest)
Requires:       python3dist(flaky)
Requires:       python3dist(pyside6)
Requires:       python3dist(matplotlib)
Requires:       python3dist(urllib3)
Requires:       python3dist(idna)
Requires:       python3dist(charset-normalizer)
Requires:       python3dist(pytz)
Requires:       python3dist(python-dateutil)
Requires:       python3dist(kiwisolver)
Requires:       python3dist(pyparsing)
Requires:       python3dist(fonttools)
Requires:       python3dist(cycler)
Requires:       python3dist(contourpy)
Requires:       python3dist(six)
%if %{with mpi}
Requires:       python3dist(mpi4py)
%endif

Provides:       cobaya = %{version}-%{release}

%description -n python3-cobaya
Cobaya (code for bayesian analysis, and Spanish for Guinea Pig) is a
framework for sampling and statistical modelling: it allows you to
explore an arbitrary prior or posterior using a range of Monte Carlo
samplers (including some advanced MCMC and nested samplers). The
results of the sampling can be analysed with GetDist. It supports MPI
parallelization.


%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install

rm -rf %{buildroot}%{python3_sitelib}/example_external_likelihood/
rm -rf %{buildroot}%{python3_sitelib}/docs/

%files -n python3-cobaya
%doc README.rst
%{_bindir}/cobaya*
%{python3_sitelib}/cobaya/
%{python3_sitelib}/%{pypi_name}-%{version}.dist-info/


%changelog
* Mon Dec 09 2024 eatdirt <eatdirt> 3.5.4-1.mga10
+ Revision: 2123203
- Update to version 3.5.4

* Sat May 04 2024 eatdirt <eatdirt> 3.5.1-1.mga10
+ Revision: 2062171
- Update to version 3.5.1

* Mon Apr 15 2024 eatdirt <eatdirt> 3.5-3.mga10
+ Revision: 2057795
+ rebuild (emptylog)

* Sat Apr 06 2024 eatdirt <eatdirt> 3.5-2.mga10
+ Revision: 2055276
- Add conditionals for mpi support

* Sat Mar 09 2024 daviddavid <daviddavid> 3.5-1.mga10
+ Revision: 2048829
- new version: 3.5
- rebuild for py3.12

* Wed Aug 23 2023 eatdirt <eatdirt> 3.3.2-1.mga10
+ Revision: 1964904
- Update to version 3.3.2

* Fri Jun 09 2023 eatdirt <eatdirt> 3.3.1-4.mga9
+ Revision: 1961453
- Fix missing attribute in mcmc object

* Fri Jun 02 2023 eatdirt <eatdirt> 3.3.1-3.mga9
+ Revision: 1960558
- Fix bug in camb module

* Tue May 30 2023 eatdirt <eatdirt> 3.3.1-2.mga9
+ Revision: 1959853
- Fix python3dist requires names

* Tue May 30 2023 eatdirt <eatdirt> 3.3.1-1.mga9
+ Revision: 1959819
- imported package python-cobaya

